==> haskell-reflection-2.1.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reflection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.3
id: reflection-2.1.3-4SrNpWQSBW2LTCJ2jLk3f1
key: reflection-2.1.3-4SrNpWQSBW2LTCJ2jLk3f1
license: BSD-3-Clause
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
abi: d5e50dcee1bc213a020f67641ff20664
exposed: True
exposed-modules:
    Data.Reflection
import-dirs: /usr/lib/ghc-8.4.3/site-local/reflection-2.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/reflection-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/reflection-2.1.3
hs-libraries: HSreflection-2.1.3-4SrNpWQSBW2LTCJ2jLk3f1
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reflection-2.1.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-reflection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.4
id: reflection-2.1.4-ET4Qfoy5lmWBopRK3ezJIQ
key: reflection-2.1.4-ET4Qfoy5lmWBopRK3ezJIQ
license: BSD-3-Clause
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.schoolofhaskell.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
abi: 9287f3432288cf494e6469a0d7445dde
exposed: True
exposed-modules:
    Data.Reflection
import-dirs: /usr/lib/ghc-8.4.3/site-local/reflection-2.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/reflection-2.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/reflection-2.1.4
hs-libraries: HSreflection-2.1.4-ET4Qfoy5lmWBopRK3ezJIQ
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
